// Build don't link:
// Origin: Jakub Jelinek <jakub@redhat.com>

// crash test - XFAIL *-*-*

class v
{
    double x, y;
public:
    v();
};

class w : public v {
public :
    static const w X;
    w();
};

void bar(w x);

void foo()
{
  bar(w::X);
}
